==> ejc-budgetmanage-impl-3.0.0-20220330.112743-39-sources.jar: com/ejianc/business/change/controller/ChangeestimatesummaryController.java <==
package com.ejianc.business.change.controller;

import java.io.Serializable;

import com.ejianc.business.bedget.bean.EstimatesummaryEntity;
import com.ejianc.business.bedget.bean.EstimatesummarydetailEntity;
import com.ejianc.business.bedget.service.IEstimatesummaryService;
import com.ejianc.business.change.bean.ChangeestimatesummaryEntity;
import com.ejianc.business.change.service.IChangeestimatesummaryService;
import com.ejianc.business.change.vo.ChangeestimatesummaryVO;
import com.ejianc.business.change.vo.ChangeestimatesummarydetailVO;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.util.ExcelExport;
import com.ejianc.support.idworker.util.IdWorker;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;



/**
 * 设计概算汇总表变更
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("changeestimatesummary")
public class ChangeestimatesummaryController implements Serializable {
	private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;

    private static final String BILL_CODE = "change-budgetmanage-budgetestimatesummary";//此处需要根据实际修改

    @Autowired
    private IChangeestimatesummaryService service;

    @Autowired
    private IEstimatesummaryService estimatesummaryService;
    /**
     * 初始化更详情页面
     *
     * @param id
     * @return
     */
    @GetMapping(value = "queryDetailByEstimatesummaryId")
    @ResponseBody
    public CommonResponse<ChangeestimatesummaryVO> queryDetailByEstimatesummaryId(@RequestParam(value = "estimatesummaryId") Long estimatesummaryId) {
        EstimatesummaryEntity quotaanalysisVO = estimatesummaryService.selectById(estimatesummaryId);
        ChangeestimatesummaryVO changeVO = BeanMapper.map(quotaanalysisVO, ChangeestimatesummaryVO.class);
        Long id = IdWorker.getId();
        changeVO.setBudgetestimatesummarId(estimatesummaryId);
        changeVO.setBillState(null);
        changeVO.setCreateTime(null);
        changeVO.setCreateUserCode(null);
        changeVO.setTenantId(null);
        changeVO.setUpdateTime(null);
        changeVO.setUpdateUserCode(null);
        changeVO.setId(id);

        //限额设计指标分析清单
        List<EstimatesummarydetailEntity> estimatesummarydetailEntityList = quotaanalysisVO.getEstimatesummarydetailEntities();
        if(estimatesummarydetailEntityList!=null&&estimatesummarydetailEntityList.size()>0){
            List<ChangeestimatesummarydetailVO> changedesignestimatedetailVOS = new ArrayList<>();
            for(EstimatesummarydetailEntity entity : estimatesummarydetailEntityList){
                ChangeestimatesummarydetailVO vo = BeanMapper.map(entity, ChangeestimatesummarydetailVO.class);
                vo.setChangeMid(estimatesummaryId);
                vo.setCreateTime(null);
                vo.setCreateUserCode(null);
                vo.setTenantId(null);
                vo.setUpdateTime(null);
                vo.setUpdateUserCode(null);
                vo.setRowState("edit");
                vo.setId(IdWorker.getId());
                changedesignestimatedetailVOS.add(vo);
            }
            changeVO.setChangeestimatesummarydetailEntities(changedesignestimatedetailVOS);
        }

        return CommonResponse.success("查询详情成功！", changeVO);

    }


    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveChange", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<ChangeestimatesummaryVO> saveChange(@RequestBody ChangeestimatesummaryVO saveOrUpdateVO) {
        return service.saveChange(saveOrUpdateVO);
    }
    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<ChangeestimatesummaryVO> saveOrUpdate(@RequestBody ChangeestimatesummaryVO saveorUpdateVO) {
    	ChangeestimatesummaryEntity entity = BeanMapper.map(saveorUpdateVO, ChangeestimatesummaryEntity.class);
    	if(entity.getId() == null || entity.getId() == 0){
            CommonResponse<String> billCode = billCodeApi.getCodeBatchByRuleCode(BILL_CODE, InvocationInfoProxy.getTenantid());
            if(billCode.isSuccess()) {
//                entity.setCode(billCode.getData());//此处需要根据实际修改 删除本行或者下一行
                entity.setBillCode(billCode.getData());//此处需要根据实际修改 删除本行或者上一行
            }else{
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }
        }
    	service.saveOrUpdate(entity, false);
    	ChangeestimatesummaryVO vo = BeanMapper.map(entity, ChangeestimatesummaryVO.class);
    	return CommonResponse.success("保存或修改单据成功！",vo);
    }

    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<ChangeestimatesummaryVO> queryDetail(Long id) {
    	ChangeestimatesummaryEntity entity = service.selectById(id);
    	ChangeestimatesummaryVO vo = BeanMapper.map(entity, ChangeestimatesummaryVO.class);
        return CommonResponse.success("查询详情数据成功！",vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<ChangeestimatesummaryVO> vos) {
        service.removeByIds(vos.stream().map(ChangeestimatesummaryVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<ChangeestimatesummaryVO>> queryList(@RequestBody QueryParam param) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        /** 租户隔离 */
        //param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
//        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));

        IPage<ChangeestimatesummaryEntity> page = service.queryPage(param,false);
        IPage<ChangeestimatesummaryVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
  		pageData.setRecords(BeanMapper.mapList(page.getRecords(), ChangeestimatesummaryVO.class));

        return CommonResponse.success("查询列表数据成功！",pageData);
    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        param.getParams().put("tenant_id",new Parameter(QueryParam.EQ,InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
//        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<ChangeestimatesummaryEntity> list = service.queryList(param);
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", list);
        ExcelExport.getInstance().export("Changeestimatesummary-export.xlsx", beans, response);
    }

    /**
     * @Description 参照
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/refChangeestimatesummaryData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<ChangeestimatesummaryVO>> refChangeestimatesummaryData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        //param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if(StringUtils.isNotEmpty(condition)){
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }

        IPage<ChangeestimatesummaryEntity> page = service.queryPage(param,false);
        IPage<ChangeestimatesummaryVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), ChangeestimatesummaryVO.class));

        return CommonResponse.success("查询参照数据成功！",pageData);
     }
}

==> ejc-budgetmanage-impl-3.0.0-20220404.033202-49-sources.jar: com/ejianc/business/change/controller/ChangeestimatesummaryController.java <==
package com.ejianc.business.change.controller;

import java.io.Serializable;

import com.ejianc.business.bedget.bean.EstimatesummaryEntity;
import com.ejianc.business.bedget.bean.EstimatesummarydetailEntity;
import com.ejianc.business.bedget.service.IEstimatesummaryService;
import com.ejianc.business.bedget.vo.EstimatesummarydetailVO;
import com.ejianc.business.change.bean.ChangeestimatesummaryEntity;
import com.ejianc.business.change.service.IChangeestimatesummaryService;
import com.ejianc.business.change.vo.ChangeestimatesummaryVO;
import com.ejianc.business.change.vo.ChangeestimatesummarydetailVO;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.util.ExcelExport;
import com.ejianc.support.idworker.util.IdWorker;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.*;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;



/**
 * 设计概算汇总表变更
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("changeestimatesummary")
public class ChangeestimatesummaryController implements Serializable {
	private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;

    private static final String BILL_CODE = "change-budgetmanage-budgetestimatesummary";//此处需要根据实际修改

    @Autowired
    private IChangeestimatesummaryService service;

    @Autowired
    private IEstimatesummaryService estimatesummaryService;
    /**
     * 初始化更详情页面
     *
     * @param id
     * @return
     */
    @GetMapping(value = "queryDetailByEstimatesummaryId")
    @ResponseBody
    public CommonResponse<ChangeestimatesummaryVO> queryDetailByEstimatesummaryId(@RequestParam(value = "estimatesummaryId") Long estimatesummaryId) {
        EstimatesummaryEntity quotaanalysisVO = estimatesummaryService.selectById(estimatesummaryId);
        ChangeestimatesummaryVO changeVO = BeanMapper.map(quotaanalysisVO, ChangeestimatesummaryVO.class);
        Long id = IdWorker.getId();
        changeVO.setBudgetestimatesummarId(estimatesummaryId);
        changeVO.setBillState(null);
        changeVO.setCreateTime(null);
        changeVO.setCreateUserCode(null);
        changeVO.setTenantId(null);
        changeVO.setUpdateTime(null);
        changeVO.setUpdateUserCode(null);
        changeVO.setId(id);

        //清单
        List<EstimatesummarydetailEntity> estimatesummarydetailEntityList = quotaanalysisVO.getEstimatesummarydetailEntities();
        if(estimatesummarydetailEntityList!=null&&estimatesummarydetailEntityList.size()>0){
            List<ChangeestimatesummarydetailVO> changedesignestimatedetailVOS = new ArrayList<>();
            for(EstimatesummarydetailEntity entity : estimatesummarydetailEntityList){
                ChangeestimatesummarydetailVO vo = BeanMapper.map(entity, ChangeestimatesummarydetailVO.class);
                vo.setChangeMid(estimatesummaryId);
                vo.setOriginalId(entity.getId());
                vo.setCreateTime(null);
                vo.setCreateUserCode(null);
                vo.setTenantId(null);
                vo.setUpdateTime(null);
                vo.setUpdateUserCode(null);
                vo.setRowState("edit");
                vo.setId(IdWorker.getId());
                changedesignestimatedetailVOS.add(vo);
            }

            changeVO.setChangeestimatesummarydetailEntities(handleChildren(changedesignestimatedetailVOS));
        }

        return CommonResponse.success("查询详情成功！", changeVO);

    }


    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveChange", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<ChangeestimatesummaryVO> saveChange(@RequestBody ChangeestimatesummaryVO saveOrUpdateVO) {
        return service.saveChange(saveOrUpdateVO);
    }
    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<ChangeestimatesummaryVO> saveOrUpdate(@RequestBody ChangeestimatesummaryVO saveorUpdateVO) {
    	ChangeestimatesummaryEntity entity = BeanMapper.map(saveorUpdateVO, ChangeestimatesummaryEntity.class);
    	if(entity.getId() == null || entity.getId() == 0){
            CommonResponse<String> billCode = billCodeApi.getCodeBatchByRuleCode(BILL_CODE, InvocationInfoProxy.getTenantid());
            if(billCode.isSuccess()) {
//                entity.setCode(billCode.getData());//此处需要根据实际修改 删除本行或者下一行
                entity.setBillCode(billCode.getData());//此处需要根据实际修改 删除本行或者上一行
            }else{
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }
        }
    	service.saveOrUpdate(entity, false);
    	ChangeestimatesummaryVO vo = BeanMapper.map(entity, ChangeestimatesummaryVO.class);
    	return CommonResponse.success("保存或修改单据成功！",vo);
    }

    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<ChangeestimatesummaryVO> queryDetail(Long id) {
    	ChangeestimatesummaryEntity entity = service.selectById(id);
    	ChangeestimatesummaryVO vo = BeanMapper.map(entity, ChangeestimatesummaryVO.class);

        List<ChangeestimatesummarydetailVO> estimatesummarydetailVOList = vo.getChangeestimatesummarydetailEntities();
        vo.setChangeestimatesummarydetailEntities(handleChildren(estimatesummarydetailVOList));
        return CommonResponse.success("查询详情数据成功！",vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<ChangeestimatesummaryVO> vos) {
        return service.delete(vos);
    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<ChangeestimatesummaryVO>> queryList(@RequestBody QueryParam param) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        /** 租户隔离 */
        //param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
//        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));

        IPage<ChangeestimatesummaryEntity> page = service.queryPage(param,false);
        IPage<ChangeestimatesummaryVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
  		pageData.setRecords(BeanMapper.mapList(page.getRecords(), ChangeestimatesummaryVO.class));

        return CommonResponse.success("查询列表数据成功！",pageData);
    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        param.getParams().put("tenant_id",new Parameter(QueryParam.EQ,InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
//        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<ChangeestimatesummaryEntity> list = service.queryList(param);
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", list);
        ExcelExport.getInstance().export("Changeestimatesummary-export.xlsx", beans, response);
    }

    /**
     * @Description 参照
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/refChangeestimatesummaryData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<ChangeestimatesummaryVO>> refChangeestimatesummaryData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        //param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if(StringUtils.isNotEmpty(condition)){
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }

        IPage<ChangeestimatesummaryEntity> page = service.queryPage(param,false);
        IPage<ChangeestimatesummaryVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), ChangeestimatesummaryVO.class));

        return CommonResponse.success("查询参照数据成功！",pageData);
     }

    /**
     * 对子表做排序、构建树等处理
     * @param voList
     */
    private List<ChangeestimatesummarydetailVO> handleChildren(List<ChangeestimatesummarydetailVO> voList) {
        //按子目编码排序
        Collections.sort(voList, new Comparator<ChangeestimatesummarydetailVO>() {
            @Override
            public int compare(ChangeestimatesummarydetailVO o1, ChangeestimatesummarydetailVO o2) {
                return o1.getInventoryCode().compareTo(o2.getInventoryCode());
            }
        });

        //构建树
        voList = createTreeData(voList);

        return voList;
    }

    public static List<ChangeestimatesummarydetailVO> createTreeData(List<ChangeestimatesummarydetailVO> list) {
        List<ChangeestimatesummarydetailVO> resp = new ArrayList<>();
        List<String> rootItems = new ArrayList<String>();

        //循环list，放入listMap重
        Map<String, ChangeestimatesummarydetailVO> listMap = new HashMap<>();
        for(ChangeestimatesummarydetailVO item:list) {
            listMap.put(item.getTid().toString(), item);
        }

        for(int i =0; i<list.size(); i++) {
            ChangeestimatesummarydetailVO item = list.get(i);
            String parentId = (item.getTpid() != null) ? item.getTpid().toString():"";
            ChangeestimatesummarydetailVO parent = listMap.get(parentId);
            if(parent != null) {
                List<ChangeestimatesummarydetailVO> child = (List<ChangeestimatesummarydetailVO>) parent.getChildren();
                if(child != null) {
                    child.add(item);
                }else{
                    List<ChangeestimatesummarydetailVO> children = new ArrayList<>();
                    children.add(item);
                    parent.setChildren(children);
                }
            } else {
                rootItems.add(item.getTid());
            }
        }

        for(String rootId : rootItems) {
            resp.add(listMap.get(rootId));
        }

        return resp;
    }
}
